ClientStorageThreadHandle

Struct ClientStorageThreadHandle 

pub struct ClientStorageThreadHandle {
    sender: GenericSender<ClientStorageThreadMessage>,
}

Fields

sender: GenericSender<ClientStorageThreadMessage>

Implementations

Source

impl ClientStorageThreadHandle

pub fn new(sender: GenericSender<ClientStorageThreadMessage>) -> Self

pub fn obtain_a_storage_bottle_map( &self, storage_type: StorageType, webview: Option<WebViewId>, storage_identifier: StorageIdentifier, origin: ImmutableOrigin, ) -> GenericReceiver<Result<StorageProxyMap, String>>

pub fn create_database( &self, bottle_id: i64, name: String, ) -> GenericReceiver<Result<(PathBuf, bool), String>>

pub fn delete_database( &self, bottle_id: i64, name: String, ) -> GenericReceiver<Result<(), String>>

pub fn persisted( &self, origin: ImmutableOrigin, sender: GenericCallback<Result<bool, String>>, ) -> SendResult

pub fn persist( &self, origin: ImmutableOrigin, permission_granted: bool, sender: GenericCallback<Result<bool, String>>, ) -> SendResult

pub fn estimate( &self, origin: ImmutableOrigin, sender: GenericCallback<Result<(u64, u64), String>>, ) -> SendResult

Methods from Deref<Target = GenericSender<ClientStorageThreadMessage>>

pub fn send(&self, msg: T) -> Result<(), SendError>

pub fn send_or_warn(&self, msg: T)

Send a message T and log any error (instead of returning it).

In cases where channel closure is possible (because the receiver does not exist anymore), this convenience method can be used to ignore the result and log the error as a warning.

pub fn send_or_ignore(&self, msg: T)

Send a message T and ignore the result

In cases where channel closure is expected to happen intermittently, and the sender doesn’t care about the result, this is a short form for let _ = GenericSender::send();, which makes the intent clearer.